@@ -18,7 +18,7 @@
  *
  * May, 2000. Implemented on FreeBSD 4.0-RELEASE (Compaq Armada M700)
  *
- $Id: battstat_applet.c,v 1.31 2002/02/16 22:03:08 bratsche Exp $
+ $Id: battstat_applet.c,v 1.33 2002/02/24 04:20:21 hadess Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -299,12 +299,6 @@ pixmap_timeout( gpointer data )
   ProgressData *battery = data;
 /*   MeterData *meter; */
   GdkColor *color, *darkcolor;
-  static guint flash=FALSE;
-  static guint last_batt_life=1000;
-  static guint last_acline_status=1000;
-  static guint last_batt_state=1000;
-  static guint last_pixmap_index=1000;
-  static guint last_charging=1000;
   guint batt_life;
   guint acline_status;
   guint batt_state;
@@ -382,14 +376,14 @@ pixmap_timeout( gpointer data )
   if(batt_life == 100) charging = FALSE;
   if(!acline_status) charging = FALSE;
  
-   flash = flash ? FALSE : TRUE;
+   battery->flash = battery->flash ? FALSE : TRUE;
 
    pixmap_index = (acline_status) ?
-              (charging && flash ? FLASH : AC) :
+              (charging && battery->flash ? FLASH : AC) :
               (batt_life <= battery->red_val ? WARNING : BATTERY)
    ;
 
-   if ( pixmap_index != last_pixmap_index ) {
+   if ( pixmap_index != battery->last_pixmap_index ) {
       gtk_pixmap_set(GTK_PIXMAP (battery->statuspixmapwid),
                      statusimage[pixmap_index], statusmask[pixmap_index]);
 #ifdef FIXME
@@ -400,8 +394,8 @@ pixmap_timeout( gpointer data )
 
    if(
      !acline_status
-     && last_batt_life != 1000
-     && last_batt_life > battery->red_val
+     && battery->last_batt_life != 1000
+     && battery->last_batt_life > battery->red_val
      && batt_life <= battery->red_val
    ) {
       /* Warn that battery dropped below red_val */
@@ -419,9 +413,9 @@ pixmap_timeout( gpointer data )
    }
 
    if(
-      last_charging
-      && last_acline_status
-      && last_acline_status!=1000
+      battery->last_charging
+      && battery->last_acline_status
+      && battery->last_acline_status!=1000
       && !charging 
       && acline_status
       && batterypresent
@@ -436,9 +430,9 @@ pixmap_timeout( gpointer data )
    }
 
    if(
-      acline_status != last_acline_status
-      || batt_life != last_batt_life
-      || batt_state != last_batt_state
+      acline_status != battery->last_acline_status
+      || batt_life != battery->last_batt_life
+      || batt_state != battery->last_batt_state
       || battery->colors_changed )
    {
       /* Something changed */
@@ -655,11 +649,11 @@ pixmap_timeout( gpointer data )
       if (DEBUG) printf("Percent: %d, Status: %s\n", batt_life, status[batt_state]);
    }
 
-   last_charging = charging;
-   last_batt_state = batt_state;
-   last_batt_life=batt_life;
-   last_acline_status = acline_status;
-   last_pixmap_index = pixmap_index;
+   battery->last_charging = charging;
+   battery->last_batt_state = batt_state;
+   battery->last_batt_life = batt_life;
+   battery->last_acline_status = acline_status;
+   battery->last_pixmap_index = pixmap_index;
 
    
    return TRUE;
@@ -686,6 +680,21 @@ destroy_applet (GtkWidget *widget, gpointer data)
    return;
 }
 
+static void
+battstat_error_dialog(gchar *msg)
+{
+	GtkWidget *dialog;
+
+	dialog = gtk_message_dialog_new(NULL,
+			0,
+			GTK_MESSAGE_ERROR,
+			GTK_BUTTONS_OK,
+			msg);
+
+	gtk_dialog_run (GTK_DIALOG(dialog));
+	gtk_widget_destroy (dialog);
+}
+
 void
 cleanup(int status)
 {
@@ -693,7 +702,7 @@ cleanup(int status)
    
    switch (status) {
     case 1:
-      g_error (
+      battstat_error_dialog (
 	       /* Displayed if the APM device couldn't be opened. (Used under *BSD)*/
 	       _("Can't open the APM device!\n\n"
 		 "Make sure you have read permission to the\n"
@@ -701,7 +710,7 @@ cleanup(int status)
       exit(1);
       break;
     case 2:
-      g_error (
+      battstat_error_dialog (
 	       /* Displayed if the APM system is disabled (Used under *BSD)*/	     
 	       _("The APM Management subsystem seems to be disabled.\n"
 		 "Try executing \"apm -e 1\" (FreeBSD) and see if \n"
@@ -739,7 +748,30 @@ suspend_cb (PanelApplet *applet, gpointer data)
    ProgressData *battstat = data;
    
    if(battstat->suspend_cmd && strlen(battstat->suspend_cmd)>0) {
-      gnome_execute_shell(NULL, battstat->suspend_cmd);
+      GError *err = NULL;
+      gboolean ret;
+      gint shell_ret = 0;
+
+      ret = g_spawn_command_line_sync(battstat->suspend_cmd,
+		      NULL, NULL, &shell_ret, &err);
+      if (ret == FALSE || shell_ret != 0)
+      {
+	      gchar *msg;
+
+	      if (err != NULL)
+	      {
+		      msg = g_strdup_printf(_("An error occured while launching the Suspend command: %s\nPlease try to correct this error"), err->message);
+	      } else {
+		      /* Probably because the shell_ret is != 0 */
+		      msg = g_strdup_printf(_("An error occured while launching the Suspend command, the command returned \"%d\"\nPlease try to correct this error"), shell_ret);
+	      }
+	      battstat_error_dialog(msg);
+	      g_free(msg);
+	      if (err != NULL)
+		      g_error_free(err);
+      }
+   } else {
+      battstat_error_dialog(_("Suspend command wasn't setup correctly in the preferences.\nPlease change the preferences and try again."));
    }
    
    return;
@@ -1390,7 +1422,13 @@ battstat_applet_fill (PanelApplet *applet)
   
   battstat->hbox1 = gtk_hbox_new (FALSE, 1);
   gtk_widget_show(battstat->hbox1);
-  
+
+  battstat->flash = FALSE;
+  battstat->last_batt_life = 1000;
+  battstat->last_acline_status = 1000;
+  battstat->last_batt_state = 1000;
+  battstat->last_pixmap_index = 1000;
+  battstat->last_charging = 1000;
   battstat->colors_changed = TRUE;
   battstat->suspend_cmd = FALSE;
   battstat->orienttype = panel_applet_get_orient (applet);
