@@ -548,15 +548,15 @@ about_cb (BonoboUIComponent *uic,
   GdkPixbuf *pixbuf;
 
   static const gchar *authors[] = {
-		"Chema Celorio <chema@celorio.com>",
 	        "Szabolcs Ban <shooby@gnome.hu>",
+		"Chema Celorio <chema@celorio.com>",
 		NULL
 	};
   static const gchar *docauthors[] = {
-	        "Szabolcs Ban <shooby@gnome.hu>",
+		"Alexander Kirillov <kirillov@math.sunysb.edu>",
 		"Emese Kovacs <emese@gnome.hu>",
 		"David Mason <dcm@redhat.com>",
-		"Alexander Kirillov <kirillov@math.sunysb.edu>",
+	        "Szabolcs Ban <shooby@gnome.hu>",
 		NULL
 	};
 	
@@ -571,16 +571,18 @@ about_cb (BonoboUIComponent *uic,
   about = gnome_about_new (_("The GNOME KeyBoard Switcher Applet"),
 			   VERSION,
 			   _("(C) 1998-2000 Free Software Foundation"),
- 			   _("This applet switches between keyboard maps. "
-			    "It uses setxkbmap, or xmodmap.\n"
-			    "Mail me your flag, please (60x40 size), "
-			    "I will put it into CVS.\n"
-			    "So long, and thanks for all the fish.\n"
-			    "Thanks for Balazs Nagy (Kevin) "
-			    "<julian7@iksz.hu> for his help "
-			    "and Emese Kovacs <emese@gnome.hu> for "
-			    "her solidarity."),
-			    authors,
+                           _("This applet switches between keyboard maps "
+                             "using setxkbmap, or xmodmap.\n"
+                             "Mail me your flag and keyboard layout"
+                             "if you want support for your locale "
+                             "(my email address is shooby@gnome.hu).\n"
+                             "So long, and thanks for all the fish.\n"
+                             "Thanks for Balazs Nagy (Kevin) "
+                              "<julian7@iksz.hu> for his help "
+                              "and Emese Kovacs <emese@gnome.hu> for "
+                              "her solidarity, help from guys like KevinV."
+                              "\nShooby Ban <shooby@gnome.hu>"),
+                            authors,
 			    docauthors,
 			    NULL,
 			    pixbuf);
@@ -722,16 +724,6 @@ find_input_client (Display * display, Window xwindow, Atom state_atom)
   return xwindow;
 }
 
-static const char gkb_menu_xml [] =
-	"<popup name=\"button3\">\n"
-	"   <menuitem name=\"GKB Properties Item\" verb=\"GKBProperties\" _label=\"Properties ...\"\n"
-	"             pixtype=\"stock\" pixname=\"gtk-properties\"/>\n"
-	"   <menuitem name=\"GKB Help Item\" verb=\"GKBHelp\" _label=\"Help\"\n"
-	"             pixtype=\"stock\" pixname=\"gtk-help\"/>\n"
-	"   <menuitem name=\"GKB About Item\" verb=\"GKBAbout\" _label=\"About ...\"\n"
-	"             pixtype=\"stock\" pixname=\"gnome-stock-about\"/>\n"
-	"</popup>\n";
-
 static const BonoboUIVerb gkb_menu_verbs [] = {
 	BONOBO_UI_UNSAFE_VERB ("GKBProperties",   properties_dialog),
 	BONOBO_UI_UNSAFE_VERB ("GKBHelp",	  help_cb),
@@ -792,10 +784,12 @@ gboolean fill_gkb_applet(PanelApplet *applet)
                           G_CALLBACK (gkb_change_pixel_size),
                           gkb);
 
-  panel_applet_setup_menu (PANEL_APPLET (gkb->applet), 
-  				gkb_menu_xml, 
-  				gkb_menu_verbs, 
-  				gkb);
+  panel_applet_setup_menu_from_file (PANEL_APPLET (gkb->applet),
+                                     NULL,
+                                     "GNOME_KeyboardApplet.xml",
+  				     NULL,
+  				     gkb_menu_verbs, 
+  				     gkb);
 
   gtk_widget_show (GTK_WIDGET(gkb->applet));
   gkb_sized_render (gkb);
