@@ -115,7 +115,7 @@
 	char *getSymsFromClist(GtkWidget *clist) ;
 
 	char *splitPrice(char *data);
-	char *splitChange(StockData *stockdata, char *data);
+	char *splitChange(StockData *stockdata, char *data, StockQuote *quote);
 
 	/* FOR COLOR */
 
@@ -133,7 +133,7 @@
 
 	
 
-        gint font_cb( GtkWidget *widget, void *data ) ;
+        void font_cb(GnomeFontPicker *gfp, const gchar *font_name, gpointer data) ;
         gint OkClicked( GtkWidget *widget, void *data ) ;
         gint QuitFontDialog( GtkWidget *widget, void *data ) ;
 	/* end font funcs and vars */
@@ -141,22 +141,22 @@
 	/*-----------------------------------------------------------------*/
 	static void load_fonts(StockData *stockdata)
 	{
+		PangoFontDescription *font;
 		
-		if (stockdata->new_font != NULL) {
-			if (stockdata->whichlabel == 1)
-				stockdata->my_font = gdk_fontset_load(stockdata->new_font);
-			else
-				stockdata->small_font = gdk_fontset_load(stockdata->new_font);
+		if (stockdata->my_font)
+			gdk_font_unref (stockdata->my_font);
+		font = pango_font_description_from_string (stockdata->props.font);
+		stockdata->my_font = gdk_font_from_description (font);
+		
+
+		if (!stockdata->extra_font) {
+			stockdata->extra_font = gdk_font_load ("-*-symbol-medium-r-normal-*-*-140-*-*-p-*-adobe-fontspecific");
 		}
-
-		if (!stockdata->my_font)
-			stockdata->my_font = gdk_fontset_load (stockdata->props.font);
-
-		if (!stockdata->extra_font)
-			stockdata->extra_font = gdk_fontset_load ("fixed");
-
-		if (!stockdata->small_font)
-			stockdata->small_font = gdk_fontset_load (stockdata->props.font2);
+		
+		if (stockdata->small_font)
+				gdk_font_unref(stockdata->small_font);
+		font = pango_font_description_from_string (stockdata->props.font2);
+		stockdata->small_font = gdk_font_from_description (font);
 
 
 		/* If fonts do not load */
@@ -167,20 +167,21 @@
 			
 			if (stockdata->extra_font)
 				gdk_font_unref(stockdata->extra_font);
-			stockdata->extra_font = gdk_fontset_load("fixed");
+			font = pango_font_description_from_string ("fixed 12");
+			stockdata->extra_font = gdk_font_from_description (font);
 			stockdata->symbolfont = 0;
 		}
 		else {
 			if (stockdata->extra_font)
 				gdk_font_unref(stockdata->extra_font);
-			stockdata->extra_font = gdk_fontset_load ("fixed");
+			stockdata->extra_font = gdk_font_load ("-*-symbol-medium-r-normal-*-*-140-*-*-p-*-adobe-fontspecific");
 			stockdata->symbolfont = 1;
 
 		}
 		if (!stockdata->small_font) {
 			if (stockdata->small_font)
 				gdk_font_unref(stockdata->small_font);
-			stockdata->small_font = gdk_fontset_load("fixed");
+			stockdata->small_font = gdk_font_load("fixed");
 		}
 
 	}
@@ -189,9 +190,9 @@
 static void xfer_callback (GnomeVFSAsyncHandle *handle, GnomeVFSXferProgressInfo *info, gpointer data)
 {
 	StockData *stockdata = data;
-g_print ("%d \n", info->phase);
+
 	if (info->phase == GNOME_VFS_XFER_PHASE_COMPLETED) {
-g_print ("completed \n");
+
 		if (!configured(stockdata)) {
 			reSetOutputArray(stockdata);
 			fprintf(stderr, "No data!\n");
@@ -205,23 +206,25 @@ g_print ("completed \n");
 static gint updateOutput(gpointer data)
 {
 	StockData *stockdata = data;
-	GList *sources = NULL, *dests = NULL;
+	GList *sources, *dests;
 	GnomeVFSURI *source_uri, *dest_uri;
-	char *source_text_uri;
+	char *source_text_uri, *dest_text_uri;
 	GnomeVFSAsyncHandle *vfshandle;
 
 	source_text_uri = g_strconcat("http://finance.yahoo.com/q?s=",
 				      stockdata->props.tik_syms,
 				      "&d=v2",
 				      NULL);
-g_print ("%s \n", source_text_uri);
+
 	source_uri = gnome_vfs_uri_new(source_text_uri);
-	sources = g_list_append(sources, source_uri);
+	sources = g_list_append(NULL, source_uri);
 	g_free(source_text_uri);
-g_print ("%s \n", stockdata->configFileName);
-	dest_uri = gnome_vfs_uri_new(stockdata->configFileName);
-	dests = g_list_append(dests, dest_uri);
-#if 0
+	dest_text_uri = g_strconcat ("file://",stockdata->configFileName, NULL);
+
+	dest_uri = gnome_vfs_uri_new(dest_text_uri);
+	dests = g_list_append(NULL, dest_uri);
+	g_free (dest_text_uri);
+
 	if (GNOME_VFS_OK !=
 	    gnome_vfs_async_xfer(&vfshandle, sources, dests,
 				 GNOME_VFS_XFER_DEFAULT,
@@ -229,21 +232,13 @@ g_print ("%s \n", stockdata->configFileName);
 				 GNOME_VFS_XFER_OVERWRITE_MODE_REPLACE,
 				 GNOME_VFS_PRIORITY_DEFAULT,
 				 (GnomeVFSAsyncXferProgressCallback) xfer_callback,
-				 stockdata, 
-				 NULL, NULL)) {
+				 stockdata, NULL, NULL)) {
 		GnomeVFSXferProgressInfo info;
-g_print ("hello \n");
+
 		info.phase = GNOME_VFS_XFER_PHASE_COMPLETED;
 		xfer_callback(NULL, &info, stockdata);
 	}
-#else
-	gnome_vfs_xfer_uri (source_uri, dest_uri, GNOME_VFS_XFER_DEFAULT,
-			    GNOME_VFS_XFER_ERROR_MODE_ABORT,
-			    GNOME_VFS_XFER_OVERWRITE_MODE_REPLACE,
-			    NULL,
-			    NULL);
-	configured (stockdata);
-#endif
+
 	g_list_free(sources);
 	g_list_free(dests);
 
@@ -264,7 +259,7 @@ g_print ("hello \n");
 									   "tik_syms",
 									   NULL);
 		if (!stockdata->props.tik_syms)
-			stockdata->props.tik_syms = g_strdup ("cald+rhat+corl");
+			stockdata->props.tik_syms = g_strdup ("^DJI+^IXIC+^GSPC");
 		stockdata->props.output = panel_applet_gconf_get_bool (applet,
 									  "output",
 									  NULL);
@@ -372,7 +367,7 @@ g_print ("hello \n");
 		int flag=0;
 		char *section = NULL;
 		char *ptr;
-g_print ("parse \n");
+
 		if (strlen(line) > 64) AllOneLine=1;
 
 		if (AllOneLine) {
@@ -436,7 +431,6 @@ g_print ("parse \n");
 			}
 			linenum++;
 		}
-		g_print ("%s \n", change);
 		sprintf(result,"%s:%s:%s:%s",
 				symbol,price,change,percent);			
 		return(result);
@@ -453,7 +447,7 @@ g_print ("parse \n");
 		static FILE *CONFIG;
 
 		CONFIG = fopen((const char *)stockdata->configFileName,"r");
-g_print ("configured \n");
+
 		retVar = 0;
 
 		/* clear the output variable */
@@ -743,6 +737,8 @@ g_print ("configured \n");
 		StockData *stockdata = data;
 		PanelApplet *applet = PANEL_APPLET (stockdata->applet);
 		
+		if (gtk_toggle_button_get_active (button) == stockdata->props.output)
+			return;
 		stockdata->props.output = gtk_toggle_button_get_active (button);
 		panel_applet_gconf_set_bool (applet,"output",
 					     stockdata->props.output, NULL);
@@ -767,9 +763,19 @@ g_print ("configured \n");
 		StockData *stockdata = data;
 		PanelApplet *applet = PANEL_APPLET (stockdata->applet);
 		
+		if (stockdata->props.arrows == gtk_toggle_button_get_active (button))
+			return;
+			
 		stockdata->props.arrows = gtk_toggle_button_get_active (button);
 		panel_applet_gconf_set_bool (applet,"arrows",
 					     stockdata->props.arrows, NULL);
+		load_fonts (stockdata);
+		if (!configured(stockdata)) {
+			reSetOutputArray(stockdata);
+			fprintf(stderr, "No data!\n");
+			setOutputArray(stockdata,
+				       _("No data available or properties not set"));
+		}
 					     
 	}
 	
@@ -847,7 +853,6 @@ g_print ("configured \n");
 		if (!symbol)
 			return;
 		
-		g_print ("%s \n", symbol);
 		tmp = stockdata->props.tik_syms;
 		/* don't add the "+" if the symbol is the first one */
 		if (stockdata->props.tik_syms)
@@ -891,92 +896,38 @@ g_print ("configured \n");
 		
 	}
 
-#ifdef FIXME
-	/*-----------------------------------------------------------------*/
-	static void apply_cb( GtkWidget *widget, void *data ) {
-
-		char *tmpText;
-#ifdef FIXME
-		if (new_font != NULL) {
-			if (whichlabel == 1) 
-				props.font = g_strdup(new_font);
-			else
-				props.font2 = g_strdup(new_font);
-		}
+	void font_cb(GnomeFontPicker *gfp, const gchar *font_name, gpointer data) {
+		StockData *stockdata = data;
+		PanelApplet *applet = PANEL_APPLET (stockdata->applet);
 		
+		if (!font_name)
+			return; 
+		
+		if (stockdata->props.font)
+			g_free (stockdata->props.font);
+		stockdata->props.font = g_strdup (font_name);
+		load_fonts (stockdata);
+		panel_applet_gconf_set_string (applet,"font",
+					       stockdata->props.font, NULL);
 
-		properties_set(TRUE);
-#endif
 	}
 
-
-	/*-----------------------------------------------------------------*/
-        static gint font_selector( GtkWidget *widget, void *data ) {
-
-		if (!fontDialog) {
-			fontDialog = gtk_font_selection_dialog_new("Font Selector");
-			gtk_signal_connect (GTK_OBJECT (GTK_FONT_SELECTION_DIALOG(fontDialog)->ok_button),
-					    "clicked",
-					    GTK_SIGNAL_FUNC(OkClicked),fontDialog);
-            		gtk_signal_connect_object(GTK_OBJECT(GTK_FONT_SELECTION_DIALOG(fontDialog)->cancel_button),
-						  "clicked",
-						  GTK_SIGNAL_FUNC(gtk_widget_destroy),
-						  GTK_OBJECT(fontDialog));
-            		gtk_signal_connect (GTK_OBJECT (fontDialog), "destroy",
-					    GTK_SIGNAL_FUNC(QuitFontDialog),
-					    fontDialog);
+        /*-----------------------------------------------------------------*/
+	static void font2_cb(GnomeFontPicker *gfp, const gchar *font_name, gpointer data) {
+		StockData *stockdata = data;
+		PanelApplet *applet = PANEL_APPLET (stockdata->applet);
+		
+		if (!font_name)
+			return;
 			
-            		gtk_widget_show(fontDialog);
-		} else
-			gdk_window_raise(fontDialog->window);
-		
-		return FALSE;
-	}
-#endif	
-        /*-----------------------------------------------------------------*/
+		stockdata->props.font2 = g_strdup (font_name);
+		load_fonts (stockdata);
+		panel_applet_gconf_set_string (applet,"font2",
+					       stockdata->props.font2, NULL);
 
-	gint font_cb(GtkWidget *widget, gpointer data) {
-#ifdef FIXME
-		whichlabel = 1;
-		font_selector(widget,data);
-#endif
-		return FALSE;
 	}
 
-        /*-----------------------------------------------------------------*/
-	static gint font2_cb(GtkWidget *widget, gpointer data) {
-#ifdef FIXME
-		whichlabel = 2;
-		font_selector(widget,data);
-#endif
-		return FALSE;
-	}
-
-        /*-----------------------------------------------------------------*/
-        gint OkClicked( GtkWidget *widget, void *fontDialog ) {
-#ifdef FIXME
-                gchar *newFont = NULL;
-
-
-                GtkFontSelectionDialog *fsd = 
-			GTK_FONT_SELECTION_DIALOG(fontDialog);
-
-                newFont = gtk_font_selection_dialog_get_font_name(fsd);
-                new_font = g_strdup(newFont);
-                gtk_widget_destroy(fontDialog);
-#endif
-		return FALSE;
-        }
-
-        /*-----------------------------------------------------------------*/
-        gint QuitFontDialog( GtkWidget *widget, void *data ) {
-        
-		/*fontDialog = NULL;*/
-	
-		return FALSE;
-        }
-
-	static void populatelist(StockData *stockdata, GtkWidget *list) {
+        static void populatelist(StockData *stockdata, GtkWidget *list) {
 	
 		gchar *symbol;
 		gchar *syms;
@@ -1078,7 +1029,7 @@ g_print ("configured \n");
 
 		hbox = gtk_hbox_new(FALSE,5);
 
-		button = gtk_button_new_with_label(_("Remove Selected"));
+		button = gtk_button_new_with_mnemonic(_("_Remove Selected"));
 		g_object_set_data (G_OBJECT (button), "list", list);
 		g_signal_connect (G_OBJECT (button), "clicked",
 				  G_CALLBACK (remove_symbol), stockdata);
@@ -1120,6 +1071,7 @@ g_print ("configured \n");
 		GtkObject *timeout_a;
 		GtkWidget *upColor, *downColor, *upLabel, *downLabel;
 		GtkWidget *check, *check2, *check3, *check4, *fontButton;
+		GtkWidget *font_picker;
 
 		int ur,ug,ub, dr,dg,db; 
 
@@ -1243,26 +1195,23 @@ g_print ("configured \n");
 		vbox3 = gtk_vbox_new(FALSE, 5); 
 		hbox3 = gtk_hbox_new(FALSE, 5);
 		label5 = gtk_label_new(_("Stock Symbol:"));
-                fontButton = gtk_button_new_with_label(_("Select Font"));
-                gtk_box_pack_start_defaults(GTK_BOX(hbox3),label5);
-                gtk_box_pack_start_defaults(GTK_BOX(hbox3),fontButton);
-                gtk_box_pack_start_defaults(GTK_BOX(vbox3),hbox3);
-                gtk_signal_connect_object(GTK_OBJECT(fontButton),"clicked",
-                                GTK_SIGNAL_FUNC(font_cb),GTK_OBJECT(stockdata->pb));
-                gtk_signal_connect_object(GTK_OBJECT(fontButton),"clicked",
-                                GTK_SIGNAL_FUNC(changed_cb),GTK_OBJECT(stockdata->pb));
 
+		font_picker = gnome_font_picker_new ();
+		gtk_box_pack_start_defaults(GTK_BOX(hbox3),label5);
+                gtk_box_pack_start_defaults(GTK_BOX(hbox3),font_picker);
+                gtk_box_pack_start_defaults(GTK_BOX(vbox3),hbox3);
+                g_signal_connect (G_OBJECT (font_picker), "font_set",
+                		  G_CALLBACK (font_cb), stockdata);
+                                
 		hbox3 = gtk_hbox_new(FALSE, 5);
 		label5 = gtk_label_new(_("Stock Change:"));
-                fontButton = gtk_button_new_with_label(_("Select Font"));
+                font_picker = gnome_font_picker_new ();
                 gtk_box_pack_start_defaults(GTK_BOX(hbox3),label5);
-                gtk_box_pack_start_defaults(GTK_BOX(hbox3),fontButton);
+                gtk_box_pack_start_defaults(GTK_BOX(hbox3),font_picker);
                 gtk_box_pack_start_defaults(GTK_BOX(vbox3),hbox3);
-                gtk_signal_connect_object(GTK_OBJECT(fontButton),"clicked",
-                                GTK_SIGNAL_FUNC(font2_cb),GTK_OBJECT(stockdata->pb));
-                gtk_signal_connect_object(GTK_OBJECT(fontButton),"clicked",
-                                GTK_SIGNAL_FUNC(changed_cb),GTK_OBJECT(stockdata->pb));
-
+                g_signal_connect (G_OBJECT(font_picker),"font_set",
+                                  G_CALLBACK(font2_cb),stockdata);
+                
 		gtk_box_pack_start_defaults(GTK_BOX(panela),vbox3);
 
 
@@ -1281,13 +1230,6 @@ g_print ("configured \n");
 		gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox, label);
 		label = gtk_label_new_with_mnemonic (_("_Appearance"));
 		gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox2, label);
-		
-
-#if 0
-		gtk_signal_connect_object(GTK_OBJECT(tik_syms_entry), 
-				   "changed",GTK_SIGNAL_FUNC(changed_cb),
-				   GTK_OBJECT(pb));
-#endif
 
 		gtk_widget_show_all(stockdata->pb);
 		
@@ -1304,17 +1246,6 @@ g_print ("configured \n");
         	BONOBO_UI_VERB_END
 	};
 
-	static const char gtik_applet_menu_xml [] =
-		"<popup name=\"button3\">\n"
-		"   <menuitem name=\"Item 1\" verb=\"Props\" _label=\"Properties\"\n"
-		"             pixtype=\"stock\" pixname=\"gtk-properties\"/>\n"
-		"   <menuitem name=\"Item 2\" verb=\"Refresh\" _label=\"Refresh\"\n"
-		"             pixtype=\"stock\" pixname=\"gtk-refresh\"/>\n"
-		"   <menuitem name=\"Item 3\" verb=\"About\" _label=\"About\"\n"
-		"             pixtype=\"stock\" pixname=\"gnome-stock-about\"/>\n"
-		"</popup>\n";
-
-
 	/*-----------------------------------------------------------------*/
 	static gboolean gtik_applet_fill (PanelApplet *applet){
 		StockData *stockdata;
@@ -1383,13 +1314,15 @@ g_print ("configured \n");
 		properties_load(stockdata);
 		properties_set(stockdata,FALSE);
 		
-		panel_applet_setup_menu (PANEL_APPLET (applet),
-				         gtik_applet_menu_xml,
-				         gtik_applet_menu_verbs,
-				         stockdata);
+		panel_applet_setup_menu_from_file (PANEL_APPLET (applet),
+                                                   NULL,
+				                   "GNOME_GtikApplet.xml",
+                                                   NULL,
+				                   gtik_applet_menu_verbs,
+				                   stockdata);
 
 		/* KEEPING TIMER ID FOR CLEANUP IN DESTROY */
-		stockdata->drawTimeID = gtk_timeout_add(100,Repaint,stockdata);
+		stockdata->drawTimeID = gtk_timeout_add(4,Repaint,stockdata);
 		stockdata->updateTimeID = gtk_timeout_add(stockdata->props.timeout * 60000,
 				                          updateOutput,stockdata);
 
@@ -1418,6 +1351,7 @@ g_print ("configured \n");
 	}
 
 	PANEL_APPLET_BONOBO_FACTORY ("OAFIID:GNOME_GtikApplet_Factory",
+				PANEL_TYPE_APPLET,
 			     	"Gtik applet",
 			     	"0",
 			     	gtik_applet_factory,
@@ -1476,7 +1410,7 @@ g_print ("configured \n");
 	}
 
 	/*-----------------------------------------------------------------*/
-	char *splitChange(StockData *stockdata,char *data) {
+	char *splitChange(StockData *stockdata,char *data, StockQuote *quote) {
 		char buff[128]="";
 		static char buff2[128]="";
 		char *var1, *var2, *var3, *var4;
@@ -1491,22 +1425,24 @@ g_print ("configured \n");
 			return data;
 
 		if (var3[0] == '+') { 
-			/*if (stockdata->symbolfont)
-				var3[0] = 221;*/
+			if (stockdata->symbolfont)
+				var3[0] = 221;
 			var4[0] = '(';
+			quote->color = GREEN;
 		}
 		else if (var3[0] == '-') {
-			/*if (stockdata->symbolfont)
-				var3[0] = 223;	*/
+			if (stockdata->symbolfont)
+				var3[0] = 223;	
 			var4[0] = '(';
+			quote->color = RED;
 		}
 		else {
 			var3 = g_strdup(_("(No"));
 			var4 = g_strdup(_("Change "));
+			quote->color = WHITE;
 		}
 
 		sprintf(buff2,"%s %s)",var3,var4);
-		g_print ("%s %s change \n", var4, var3);
 		return(buff2);
 	}
 
@@ -1517,19 +1453,12 @@ g_print ("configured \n");
 		char *change;
 
 		price = splitPrice(param1);
-		change = splitChange(stockdata, param1);
+		change = splitChange(stockdata, param1, &quote);
 
 		quote.price = g_strdup(price);
 		quote.change = g_strdup(change);
 
-		if (strstr(change,"-"))
-			quote.color = RED;
-		else if (strstr(change,"+"))
-			quote.color = GREEN;
-		else
-			quote.color = WHITE;
-
-#if 1
+#if 0
 		g_message("Param1: %s\nPrice: %s\nChange: %s\nColor: %d\n\n", param1, price, change, quote.color);
 #endif
 
