@@ -19,8 +19,8 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include <string.h>
 #include <config.h>
+#include <string.h>
 #include <gnome.h>
 #include <panel-applet.h>
 #include <gdk/gdkkeysyms.h>
@@ -401,7 +401,8 @@ show_history_signal(GtkWidget *widget, gpointer data)
 static gint 
 file_browser_ok_signal(GtkWidget *widget, gpointer file_select)
 {
-    PanelApplet *applet = g_object_get_data (G_OBJECT (file_select), "applet");
+    GtkWidget *fs = file_select;
+    PanelApplet *applet = g_object_get_data (G_OBJECT (fs), "applet");
     /* get selected file name */
     strcpy(browsed_filename, (char *) gtk_file_selection_get_filename(GTK_FILE_SELECTION(file_select)));
 
@@ -422,7 +423,7 @@ gint
 show_file_browser_signal(GtkWidget *widget, gpointer data)
 {
     /* FIXME: write this routine */
-    PanelApplet *applet;
+    PanelApplet *applet = data;
     GtkWidget *file_select;
 
     /* build file select dialog */
