@@ -121,8 +121,7 @@ static void mixer_start_gmix_cb (BonoboUIComponent *uic,
 
 
 static gint mixerfd = -1;
-static gint num_applets = 0;
-static GdkPixbuf *zero_pixbuf, *min_pixbuf, *medium_pixbuf, *max_pixbuf, *mute_pixbuf;
+static GdkPixbuf *zero_pixbuf = NULL, *min_pixbuf, *medium_pixbuf, *max_pixbuf, *mute_pixbuf;
 
 
 #ifdef OSS_API
@@ -616,12 +615,6 @@ destroy_mixer_cb (GtkWidget *widget, MixerData *data)
 	}
 
 	g_free (data);
-
-	num_applets--;
-	g_print ("num left %d\n", num_applets);
-	if (num_applets == 0) {
-		bonobo_main_quit ();
-	}
 }
 
 static void
@@ -778,17 +771,6 @@ const BonoboUIVerb mixer_applet_menu_verbs [] = {
         BONOBO_UI_VERB_END
 };
 
-const gchar mixer_applet_menu_xml [] =
-"<popup name=\"button3\">\n"
-"   <menuitem name=\"RunMixer\" verb=\"RunMixer\" _label=\"Run Audio Mixer...\"/>"
-"   <menuitem name=\"Mute\" verb=\"Mute\" type=\"toggle\" _label=\"Mute\"/>"
-"   <menuitem name=\"Help\" verb=\"Help\" _label=\"Help\"\n"
-"             pixtype=\"stock\" pixname=\"gtk-help\"/>\n"
-"   <menuitem name=\"About\" verb=\"About\" _label=\"About...\"\n"
-"             pixtype=\"stock\" pixname=\"gnome-stock-about\"/>\n"
-"</popup>\n";
-
-
 static void
 mixer_applet_create (PanelApplet *applet)
 {
@@ -871,12 +853,14 @@ mixer_applet_create (PanelApplet *applet)
 			  G_CALLBACK (applet_change_background_cb),
 			  data);
 
-	panel_applet_setup_menu (PANEL_APPLET (data->applet),
-				 mixer_applet_menu_xml,
-				 mixer_applet_menu_verbs,
-				 data);
+	panel_applet_setup_menu_from_file (applet, 
+					   NULL, /* opt_datadir */
+					   "GNOME_MixerApplet.xml",
+					   NULL,
+					   mixer_applet_menu_verbs,
+					   data);
 
-	component = panel_applet_get_popup_component (PANEL_APPLET (data->applet));
+	component = panel_applet_get_popup_component (applet);
 	g_signal_connect (component,
 			  "ui-event",
 			  (GCallback) mixer_ui_component_event,
@@ -900,6 +884,7 @@ mixer_applet_factory (PanelApplet *applet,
 		      const gchar *iid,
 		      gpointer     data)
 {
+/* FIXME: remove this when libpanel-applet is fixed. */
 #ifdef ENABLE_NLS
 	static inited = FALSE;
 
@@ -913,7 +898,6 @@ mixer_applet_factory (PanelApplet *applet,
 #endif	
 
 	mixer_applet_create (applet);
-	num_applets++;
 
 	return TRUE;
 }
